@@ -3,6 +3,7 @@
 
 # imports.
 from r3sponse.v1.classes.config import *
+from django.http import JsonResponse
 
 # the manager class.
 class R3sponse(object):
@@ -16,14 +17,16 @@ class R3sponse(object):
 			"message":None,
 		}
 	def success_response(self,
-		# the message.
+		# the message (must be param #1).
 		message, 
-		# additional returnable functions.
+		# additional returnable functions (must be param #2).
 		variables={}, 
 		# log the message to the console.
 		log=False, 
 		# save the error to the logs file.
 		save=False,
+		# return as a django JsonResponse.
+		django=False,
 	):
 		response = self.default_response()
 		response["success"] = True
@@ -32,6 +35,7 @@ class R3sponse(object):
 			response[key] = value
 		if log: print(response["message"])
 		if save: self.__log_to_file__(response["message"])
+		if django: response = JsonResponse(response)
 		return response
 	def error_response(self,
 		# the error message.
@@ -40,11 +44,14 @@ class R3sponse(object):
 		log=False, 
 		# save the error to the erros file.
 		save=False,
+		# return as a django JsonResponse.
+		django=False,
 	):
 		response = self.default_response()
 		response["error"] = error
 		if log: print(response["error"])
 		if save: self.__log_to_file__(response["error"])
+		if django: response = JsonResponse(response)
 		return response
 		#
 	def load_logs(self, format="webserver", options=["webserver", "cli", "array", "string"]):
